@@ -44,12 +44,11 @@
 #include <messagestatus.h>
 #include <kmime/kmime_message.h>
 
-#include <qaction.h>
+#include <QAction>
 #include <kactioncollection.h>
 
 #include <KLocalizedString>
 
-#include <QPointer>
 #include <QItemSelectionModel>
 
 using namespace Akonadi;
@@ -60,8 +59,8 @@ public:
     Private(KActionCollection *actionCollection, QWidget *parentWidget, StandardMailActionManager *parent)
         : mActionCollection(actionCollection)
         , mParentWidget(parentWidget)
-        , mCollectionSelectionModel(0)
-        , mItemSelectionModel(0)
+        , mCollectionSelectionModel(nullptr)
+        , mItemSelectionModel(nullptr)
         , mParent(parent)
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
@@ -118,10 +117,12 @@ public:
         updateGenericAction(StandardActionManager::MoveToTrashRestoreItemAlternative);
         updateGenericAction(StandardActionManager::SynchronizeFavoriteCollections);
     }
+
     void updateGenericAction(StandardActionManager::Type type)
     {
         switch (type) {
-        case Akonadi::StandardActionManager::CreateCollection: {
+        case Akonadi::StandardActionManager::CreateCollection:
+        {
             QAction *act = mGenericManager->action(Akonadi::StandardActionManager::CreateCollection);
             act->setText(i18n("Add Folder..."));
             act->setWhatsThis(i18n("Add a new folder to the currently selected account."));
@@ -140,7 +141,7 @@ public:
                 i18n("Folder creation failed"));
             break;
         }
-        case Akonadi::StandardActionManager::CopyCollections: {
+        case Akonadi::StandardActionManager::CopyCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::CopyCollections,
                                            ki18np("Copy Folder", "Copy %1 Folders"));
             mGenericManager->action(Akonadi::StandardActionManager::CopyCollections)->setWhatsThis(
@@ -151,7 +152,6 @@ public:
                 StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,
                 ki18nc("@title:window", "Properties of Folder %1"));
             break;
-        }
         case Akonadi::StandardActionManager::DeleteCollections:
             mGenericManager->setActionText(Akonadi::StandardActionManager::DeleteCollections,
                                            ki18np("Delete Folder", "Delete %1 Folders"));
@@ -355,33 +355,24 @@ public:
             QAction *action = mActions.value(Akonadi::StandardMailActionManager::MarkMailAsRead);
             if (action) {
                 updateMarkAction(action, allMarkedAsRead);
-                if (allMarkedAsRead) {
-                    action->setEnabled(false);
-                } else {
-                    action->setEnabled(true);
-                }
+                action->setEnabled(!allMarkedAsRead);
             }
 
             action = mActions.value(Akonadi::StandardMailActionManager::MarkMailAsUnread);
             if (action) {
                 updateMarkAction(action, allMarkedAsUnread);
-                if (allMarkedAsUnread) {
-                    action->setEnabled(false);
-                } else {
-                    action->setEnabled(true);
-                }
+                action->setEnabled(!allMarkedAsUnread);
             }
 
             action = mActions.value(Akonadi::StandardMailActionManager::MarkMailAsImportant);
             if (action) {
                 action->setCheckable(true);
                 updateMarkAction(action, allMarkedAsImportant);
+                action->setChecked(allMarkedAsImportant);
                 if (allMarkedAsImportant) {
                     action->setText(i18n("Remove Important Mark"));
-                    action->setChecked(true);
                 } else {
                     action->setText(i18n("&Mark Message as Important"));
-                    action->setChecked(false);
                 }
                 action->setEnabled(true);
             }
@@ -390,12 +381,11 @@ public:
             if (action) {
                 action->setCheckable(true);
                 updateMarkAction(action, allMarkedAsActionItem);
+                action->setChecked(allMarkedAsActionItem);
                 if (allMarkedAsActionItem) {
                     action->setText(i18n("Remove Action Item Mark"));
-                    action->setChecked(true);
                 } else {
                     action->setText(i18n("&Mark Message as Action Item"));
-                    action->setChecked(false);
                 }
                 action->setEnabled(true);
             }
@@ -434,12 +424,12 @@ public:
                         canDeleteItem = collection.rights() & Akonadi::Collection::CanDeleteItem;
                     }
                     if (!isSystemFolder) {
-                        isSystemFolder = (collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Inbox) ||
-                                          collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Outbox) ||
-                                          collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::SentMail) ||
-                                          collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Trash) ||
-                                          collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Drafts) ||
-                                          collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Templates));
+                        isSystemFolder = (collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Inbox)
+                                          || collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Outbox)
+                                          || collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::SentMail)
+                                          || collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Trash)
+                                          || collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Drafts)
+                                          || collection == SpecialMailCollections::self()->defaultCollection(SpecialMailCollections::Templates));
                     }
                     //We will not change after that.
                     if (enableMarkAllAsRead && enableMarkAllAsUnread && !canDeleteItem && isSystemFolder) {
@@ -630,7 +620,9 @@ public:
         }
 
         RemoveDuplicatesJob *job = new RemoveDuplicatesJob(collections, mParent);
-        connect(job, SIGNAL(finished(KJob*)), mParent, SLOT(slotJobFinished(KJob*)));
+        connect(job, &RemoveDuplicatesJob::finished, mParent, [this](KJob *job) {
+            slotJobFinished(job);
+        });
     }
 
     void slotJobFinished(KJob *job)
@@ -669,14 +661,14 @@ public:
         command->execute();
     }
 
-    KActionCollection *mActionCollection;
-    QWidget *mParentWidget;
-    StandardActionManager *mGenericManager;
-    QItemSelectionModel *mCollectionSelectionModel;
-    QItemSelectionModel *mItemSelectionModel;
+    KActionCollection *mActionCollection = nullptr;
+    QWidget *mParentWidget = nullptr;
+    StandardActionManager *mGenericManager = nullptr;
+    QItemSelectionModel *mCollectionSelectionModel = nullptr;
+    QItemSelectionModel *mItemSelectionModel = nullptr;
     QHash<StandardMailActionManager::Type, QAction *> mActions;
     QSet<StandardMailActionManager::Type> mInterceptedActions;
-    StandardMailActionManager *mParent;
+    StandardMailActionManager *mParent = nullptr;
 };
 
 StandardMailActionManager::StandardMailActionManager(KActionCollection *actionCollection, QWidget *parent)
@@ -695,12 +687,15 @@ void StandardMailActionManager::setCollectionSelectionModel(QItemSelectionModel
     d->mCollectionSelectionModel = selectionModel;
     d->mGenericManager->setCollectionSelectionModel(selectionModel);
 
-    connect(selectionModel->model(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-            SLOT(updateActions()));
-    connect(selectionModel->model(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            SLOT(updateActions()));
-    connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(updateActions()));
+    connect(selectionModel->model(), &QAbstractItemModel::rowsInserted, this, [this]() {
+        d->updateActions();
+    });
+    connect(selectionModel->model(), &QAbstractItemModel::rowsRemoved, this, [this]() {
+        d->updateActions();
+    });
+    connect(selectionModel, &QItemSelectionModel::selectionChanged, this, [this]() {
+        d->updateActions();
+    });
 
     d->updateActions();
 }
@@ -710,12 +705,14 @@ void StandardMailActionManager::setItemSelectionModel(QItemSelectionModel *selec
     d->mItemSelectionModel = selectionModel;
     d->mGenericManager->setItemSelectionModel(selectionModel);
 
-    connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(updateActions()));
+    connect(selectionModel, &QItemSelectionModel::selectionChanged, this, [this]() {
+        d->updateActions();
+    });
 
     //to catch item modifications, listen to the model's dataChanged signal as well
-    connect(selectionModel->model(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            SLOT(updateActions()));
+    connect(selectionModel->model(), &QAbstractItemModel::dataChanged, this, [this]() {
+        d->updateActions();
+    });
 
     d->updateActions();
 }
@@ -740,7 +737,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_as_read"), action);
         action->setData(QByteArray("R"));
         d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_R));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAs();
+        });
         break;
     case MarkMailAsUnread:
         action = new QAction(d->mParentWidget);
@@ -753,7 +752,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_as_unread"), action);
         d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_U));
         action->setData(QByteArray("U"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAs();
+        });
         break;
     case MarkMailAsImportant:
         action = new QAction(d->mParentWidget);
@@ -765,7 +766,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkMailAsImportant, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_as_important"), action);
         action->setData(QByteArray("G"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAs();
+        });
         break;
     case MarkMailAsActionItem:
         action = new QAction(d->mParentWidget);
@@ -777,7 +780,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkMailAsActionItem, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_as_action_item"), action);
         action->setData(QByteArray("K"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAs();
+        });
         break;
     case MarkAllMailAsRead:
         action = new QAction(d->mParentWidget);
@@ -789,7 +794,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkAllMailAsRead, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_all_as_read"), action);
         action->setData(QByteArray("R"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAllAs();
+        });
         break;
     case MarkAllMailAsReadRecursive:
         action = new QAction(d->mParentWidget);
@@ -801,7 +808,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkAllMailAsReadRecursive, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_all_as_read_recursive"), action);
         action->setData(QByteArray(":R"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAllAs();
+        });
         break;
     case MarkAllMailAsUnread:
         action = new QAction(d->mParentWidget);
@@ -813,7 +822,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkAllMailAsUnread, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_all_as_unread"), action);
         action->setData(QByteArray("U"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAllAs();
+        });
         break;
     case MarkAllMailAsImportant:
         action = new QAction(d->mParentWidget);
@@ -825,7 +836,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkAllMailAsImportant, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_all_as_important"), action);
         action->setData(QByteArray("G"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAllAs();
+        });
         break;
     case MarkAllMailAsActionItem:
         action = new QAction(d->mParentWidget);
@@ -837,7 +850,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActions.insert(MarkAllMailAsActionItem, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_mark_all_as_action_item"), action);
         action->setData(QByteArray("K"));
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMarkAllAs();
+        });
         break;
     case MoveToTrash:
         action = new QAction(d->mParentWidget);
@@ -848,7 +863,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         action->setWhatsThis(i18n("Move selected messages to the trash folder."));
         d->mActions.insert(MoveToTrash, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_move_to_trash"), action);
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMoveToTrash()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMoveToTrash();
+        });
         break;
     case MoveAllToTrash:
         action = new QAction(d->mParentWidget);
@@ -858,7 +875,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         action->setWhatsThis(i18n("Move all messages to the trash folder."));
         d->mActions.insert(MoveAllToTrash, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_move_all_to_trash"), action);
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotMoveAllToTrash()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotMoveAllToTrash();
+        });
         break;
     case RemoveDuplicates:
         action = new QAction(d->mParentWidget);
@@ -868,7 +887,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         d->mActionCollection->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_Asterisk));
         d->mActions.insert(RemoveDuplicates, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_remove_duplicates"), action);
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotRemoveDuplicates()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotRemoveDuplicates();
+        });
         break;
     case EmptyAllTrash:
         action = new QAction(d->mParentWidget);
@@ -877,7 +898,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         action->setWhatsThis(i18n("Permanently delete all messages from all trash folders."));
         d->mActions.insert(EmptyAllTrash, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_empty_all_trash"), action);
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotEmptyAllTrash()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotEmptyAllTrash();
+        });
         break;
     case EmptyTrash:
         action = new QAction(d->mParentWidget);
@@ -886,7 +909,9 @@ QAction *StandardMailActionManager::createAction(Type type)
         action->setWhatsThis(i18n("Permanently delete all messages from the trash folder."));
         d->mActions.insert(EmptyTrash, action);
         d->mActionCollection->addAction(QStringLiteral("akonadi_empty_trash"), action);
-        connect(action, SIGNAL(triggered(bool)), this, SLOT(slotEmptyTrash()));
+        connect(action, &QAction::triggered, this, [this]() {
+            d->slotEmptyTrash();
+        });
         break;
     default:
         Q_ASSERT(false);   // should never happen
